==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiWidgets/QTileRules_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qdrawutil.h>
#include <QtCore/QVariant>
#include <QtCore/qnamespace.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTileRules(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTileRules")
    QTileRules *_ptr = reinterpret_cast<QTileRules *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QTileRules(Qt::TileRule,Qt::TileRule)
void __qt_construct_QTileRules_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTileRules(Qt::TileRule,Qt::TileRule)")
    jobject horizontalRule0 = __java_arguments[0].l;
    Qt::TileRule __qt_horizontalRule0 = qtjambi_cast<Qt::TileRule>(__jni_env, horizontalRule0);
    jobject verticalRule1 = __java_arguments[1].l;
    Qt::TileRule __qt_verticalRule1 = qtjambi_cast<Qt::TileRule>(__jni_env, verticalRule1);
    QTileRules *__qt_this = new(__qtjambi_ptr) QTileRules(Qt::TileRule(__qt_horizontalRule0), Qt::TileRule(__qt_verticalRule1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QTileRules(Qt::TileRule)
void __qt_construct_QTileRules_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTileRules(Qt::TileRule)")
    Q_UNUSED(__java_arguments)
    QTileRules *__qt_this = new(__qtjambi_ptr) QTileRules();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QTileRules(Qt::TileRule)
void __qt_construct_QTileRules_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTileRules(Qt::TileRule)")
    jobject rule0 = __java_arguments[0].l;
    Qt::TileRule __qt_rule0 = qtjambi_cast<Qt::TileRule>(__jni_env, rule0);
    QTileRules *__qt_this = new(__qtjambi_ptr) QTileRules(Qt::TileRule(__qt_rule0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QTileRules
void __qt_destruct_QTileRules(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTileRules")
    reinterpret_cast<QTileRules*>(ptr)->~QTileRules();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTileRules::QTileRules(Qt::TileRule,Qt::TileRule)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_initialize_1native__Lio_qt_widgets_QTileRules_2Lio_qt_core_Qt_00024TileRule_2Lio_qt_core_Qt_00024TileRule_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject horizontalRule0,
 jobject verticalRule1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTileRules::QTileRules(Qt::TileRule,Qt::TileRule)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = horizontalRule0;
        arguments[1].l = verticalRule1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTileRules_0, sizeof(QTileRules), typeid(QTileRules), false, &deleter_QTileRules, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTileRules::QTileRules(Qt::TileRule)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_initialize_1native__Lio_qt_widgets_QTileRules_2Lio_qt_core_Qt_00024TileRule_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject rule0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTileRules::QTileRules(Qt::TileRule)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = rule0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTileRules_2, sizeof(QTileRules), typeid(QTileRules), false, &deleter_QTileRules, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_setHorizontal_1native_1cref_1Qt_1TileRule__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint horizontal0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTileRules *__qt_this = QtJambiAPI::objectFromNativeId<QTileRules>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::TileRule __qt_horizontal0 = qtjambi_cast<Qt::TileRule>(__jni_env, horizontal0);
        __qt_this->horizontal = Qt::TileRule(__qt_horizontal0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_horizontal_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTileRules *__qt_this = QtJambiAPI::objectFromNativeId<QTileRules>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::TileRule&  __qt_value = __qt_this->horizontal;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_setVertical_1native_1cref_1Qt_1TileRule__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint vertical0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTileRules *__qt_this = QtJambiAPI::objectFromNativeId<QTileRules>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::TileRule __qt_vertical0 = qtjambi_cast<Qt::TileRule>(__jni_env, vertical0);
        __qt_this->vertical = Qt::TileRule(__qt_vertical0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_vertical_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTileRules *__qt_this = QtJambiAPI::objectFromNativeId<QTileRules>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::TileRule&  __qt_value = __qt_this->vertical;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTileRules *__qt_this = QtJambiAPI::objectFromNativeId<QTileRules>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTileRules(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTileRules>("QTileRules", "io/qt/widgets/QTileRules");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTileRules, {
        ConstructorInfo(&__qt_construct_QTileRules_0, "Lio/qt/core/Qt$TileRule;Lio/qt/core/Qt$TileRule;")
       ,ConstructorInfo(&__qt_construct_QTileRules_1, nullptr)
       ,ConstructorInfo(&__qt_construct_QTileRules_2, "Lio/qt/core/Qt$TileRule;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTileRules);
    registerMetaType<QTileRules>("QTileRules");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiWidgets/QTileRules_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qdrawutil.h>
#include <QtCore/QVariant>
#include <QtCore/qnamespace.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTileRules(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTileRules")
    QTileRules *_ptr = reinterpret_cast<QTileRules *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QTileRules(Qt::TileRule)
void __qt_construct_QTileRules_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTileRules(Qt::TileRule)")
    Q_UNUSED(__java_arguments)
    QTileRules *__qt_this = new(__qtjambi_ptr) QTileRules();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QTileRules(Qt::TileRule)
void __qt_construct_QTileRules_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTileRules(Qt::TileRule)")
    jobject rule0 = __java_arguments[0].l;
    Qt::TileRule __qt_rule0 = qtjambi_cast<Qt::TileRule>(__jni_env, rule0);
    QTileRules *__qt_this = new(__qtjambi_ptr) QTileRules(Qt::TileRule(__qt_rule0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QTileRules(Qt::TileRule,Qt::TileRule)
void __qt_construct_QTileRules_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTileRules(Qt::TileRule,Qt::TileRule)")
    jobject horizontalRule0 = __java_arguments[0].l;
    Qt::TileRule __qt_horizontalRule0 = qtjambi_cast<Qt::TileRule>(__jni_env, horizontalRule0);
    jobject verticalRule1 = __java_arguments[1].l;
    Qt::TileRule __qt_verticalRule1 = qtjambi_cast<Qt::TileRule>(__jni_env, verticalRule1);
    QTileRules *__qt_this = new(__qtjambi_ptr) QTileRules(Qt::TileRule(__qt_horizontalRule0), Qt::TileRule(__qt_verticalRule1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QTileRules
void __qt_destruct_QTileRules(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTileRules")
    reinterpret_cast<QTileRules*>(ptr)->~QTileRules();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTileRules::QTileRules(Qt::TileRule)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_initialize_1native__Lio_qt_widgets_QTileRules_2Lio_qt_core_Qt_00024TileRule_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject rule0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTileRules::QTileRules(Qt::TileRule)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = rule0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTileRules_1, sizeof(QTileRules), typeid(QTileRules), false, &deleter_QTileRules, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTileRules::QTileRules(Qt::TileRule,Qt::TileRule)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_initialize_1native__Lio_qt_widgets_QTileRules_2Lio_qt_core_Qt_00024TileRule_2Lio_qt_core_Qt_00024TileRule_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject horizontalRule0,
 jobject verticalRule1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTileRules::QTileRules(Qt::TileRule,Qt::TileRule)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = horizontalRule0;
        arguments[1].l = verticalRule1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTileRules_2, sizeof(QTileRules), typeid(QTileRules), false, &deleter_QTileRules, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_setHorizontal_1native_1cref_1Qt_1TileRule__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint horizontal0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTileRules *__qt_this = QtJambiAPI::objectFromNativeId<QTileRules>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::TileRule __qt_horizontal0 = qtjambi_cast<Qt::TileRule>(__jni_env, horizontal0);
        __qt_this->horizontal = Qt::TileRule(__qt_horizontal0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_horizontal_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTileRules *__qt_this = QtJambiAPI::objectFromNativeId<QTileRules>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::TileRule&  __qt_value = __qt_this->horizontal;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_setVertical_1native_1cref_1Qt_1TileRule__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint vertical0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTileRules *__qt_this = QtJambiAPI::objectFromNativeId<QTileRules>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::TileRule __qt_vertical0 = qtjambi_cast<Qt::TileRule>(__jni_env, vertical0);
        __qt_this->vertical = Qt::TileRule(__qt_vertical0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_vertical_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTileRules *__qt_this = QtJambiAPI::objectFromNativeId<QTileRules>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::TileRule&  __qt_value = __qt_this->vertical;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QTileRules_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTileRules *__qt_this = QtJambiAPI::objectFromNativeId<QTileRules>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTileRules(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTileRules>("QTileRules", "io/qt/widgets/QTileRules");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTileRules, {
        ConstructorInfo(&__qt_construct_QTileRules_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QTileRules_1, "Lio/qt/core/Qt$TileRule;")
       ,ConstructorInfo(&__qt_construct_QTileRules_2, "Lio/qt/core/Qt$TileRule;Lio/qt/core/Qt$TileRule;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTileRules);
    registerMetaType<QTileRules>("QTileRules");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
